@@ -50,6 +50,7 @@ if( is.na( t.calc.P$P1 ) | t.calc.Q$Q1 == 0)
     t.ck.pred  <- NaN
     t.ck.mspe <- NaN
     t.K <- NaN
+    warning("CK predictor does not exist !!! \n  Prediction is set to NaN.")
 }
 else
 {
@@ -88,6 +89,11 @@ t.calc.Q <- f.calc.Q( 	t.skvar = t.skvar,
 
 # Berechnung der K Marix
 t.K.cmck <- tcrossprod( t.calc.Q$iQ1 , t.calc.P$P1)
+## Warnung falls Matrix K nicht existiert
+if( sum(is.nan(t.K.cmck)) > 0 )
+{
+    warning("CMCK predictor does not exist !!! \n  Prediction is set to NaN.")
+}
 # CMCK Vorhersage
 # Xm beta  + K'C'Sigma Resid  
 t.CMCK.PRED <- t.lin.trend.est + crossprod( t.K.cmck, t.weighted.resid )
