@@ -4,7 +4,7 @@ f.point.block.cov <- function(	pixconfig,
 			    )
 ### purpose: calculate the point-polygon covariance of one  polygon configuration
 ###          function returns n X m covariance matrix of n sample points and m polygons
-###          
+###
 ### arguments:
 ###           pixconfig = list,
 ###                            	1. element = t.pixel.center = Koordinaten des Schwerpunktes des linken unteren Pixels
@@ -25,12 +25,12 @@ f.point.block.cov <- function(	pixconfig,
 ###				    Beschreibt fr jeden Pixelschwerpunkt in welchem Polygon er liegt.
 ###				    zb. 17 Element der Liste mit Wert 3 bedeutet, dass der 17 Pixelschwerpunkt in Polygon 3 liegt
 ###				    interger(0) bedeutet, dass der Pixelschwerpunkt in keinem Polygonliegt
-###				    
-###				    
+###
+###
 ###           locations = n x 2 matrix (coords of the sample)
 ###           model = list mit dem covairnace model
 ###
-###				   
+###
 ### output: C = n x m Kovarianzmatrix (n = Anzahl Sttzpunkte, m = Anzahl Polygone)
 ### author: Ch. Hofer
 ### date: 9-2-2010
@@ -39,8 +39,8 @@ f.point.block.cov <- function(	pixconfig,
 
 
 ## t.n.iter Anzahl Konfigurationen ber welche die Punkt Block Kovarianz gemittelt wird
-    
-  
+
+
 t.n.iter <- as.list( 1:ceiling( dim(pixconfig$pixcenter)[2] / 2 ) )
 
 t.pb.cov.matrix.list  <- lapply( t.n.iter,
@@ -48,7 +48,7 @@ t.pb.cov.matrix.list  <- lapply( t.n.iter,
     {
 	t.col.range <- ( 2 * ( t.i-1 ) + 1 ):( 2 * ( t.i-1 ) + 2 )
 	t.pixel.center  <- matrix( pixconfig$pixcenter[ , t.col.range], ncol = 2 )
-	
+
 	t.n.poly  <- length( pixconfig$posindex )
 
 	t.col.range <- ( 1 + ( t.i - 1 ) * t.n.poly):( t.i * t.n.poly )
@@ -58,7 +58,7 @@ t.pb.cov.matrix.list  <- lapply( t.n.iter,
 	sa.polygons <- pixconfig$sa.polygons[ t.col.range ]
 	# Anzal Polygone mit einer kleineren Flche als die Flche eines Pixels
 	t.poly.as.point <- sum( sa.polygons )
-#	
+#
 	polygon.centroids <- pixconfig$polygon.centroids
 
 #	# Sttzpunkte-Polygon-Kovarianzmatrix mit NA gefllt
@@ -77,9 +77,9 @@ t.pb.cov.matrix.list  <- lapply( t.n.iter,
                                   matrix( polygon.centroids[ sa.polygons == T, ], ncol = 2)
                       	)
          	)
-  
+
   	t.pb.centroids.cov <- f.pp.cov( t.dist, model)
-  
+
   	t.pb.cov.matrix[ , sa.polygons ] <- matrix(t.pb.centroids.cov, ncol = t.poly.as.point)
 
 	} ## end if t.poly.as.point != 0)
@@ -94,43 +94,43 @@ t.pb.cov.matrix.list  <- lapply( t.n.iter,
 	{
 
 #	# t.poly.with.pixel Matrix # Zeilen = # Pixel des Pixelgrids, # Spalten = Polygone (bei CMCK)
-#	# eine 1 bedeutet, dass des entsprechende Pixel (Zeilennummer) im entsprechenden Polygon liegt (Spaltennummer)	
-    
+#	# eine 1 bedeutet, dass des entsprechende Pixel (Zeilennummer) im entsprechenden Polygon liegt (Spaltennummer)
+
     	t.poly.with.pixel.matrix <- matrix(
- 				pix.in.poly[,!sa.polygons], 
+ 				pix.in.poly[,!sa.polygons],
 				ncol = sum(!sa.polygons)
 			    )
 
-			    
+
 #	# Spalten der Matrix in Elemente einer Liste aufsplitten
 	t.poly.with.pixel.list <- split(
-  				t.poly.with.pixel.matrix, 
+  				t.poly.with.pixel.matrix,
 				col( t.poly.with.pixel.matrix)
 			    )
 
 	t.pb.pixel.cov <- lapply(t.poly.with.pixel.list,
     			function(x, locations, t.pixel.center, pixconfig, model)
 			{
-			    
+
 			    t.locations.pix.cov <- f.point.rec.covmat(
 							pxcoord  = locations[ ,1 ],
 							pycoord  = locations[ ,2 ],
 							crxcoord = t.pixel.center[ x == 1, 1 ],
 							crycoord = t.pixel.center[ x == 1, 2 ],
-							rxwidth  = pixconfig$rowwidth,
-   				 			rywidth  = pixconfig$colwidth,
-   			 	 			subdivisions = 100,
+							rxwidth  = pixconfig$colwidth,
+   				 			rywidth  = pixconfig$rowwidth,
+   			 	 			subdivisions = 1000,
    				 			param = model
 						    )$result
-			t.p.pixel.cov.matrix <- matrix( 
-				 			t.locations.pix.cov , 
+			t.p.pixel.cov.matrix <- matrix(
+				 			t.locations.pix.cov ,
     							ncol = nrow( matrix( t.pixel.center[ x == 1, ], ncol = 2 ) ),
-							nrow = nrow( locations ) 
+							nrow = nrow( locations )
 			    )
-			    
+
 			    return( rowMeans( t.p.pixel.cov.matrix ) )
 
-       
+
      			}, # end if t.poly.as.point < pixconfig$t.pixel.poly.dim[2]
 			locations = locations,
        			t.pixel.center = t.pixel.center,
@@ -139,19 +139,19 @@ t.pb.cov.matrix.list  <- lapply( t.n.iter,
 		    ) ## end apply
 	#cat("sum pb.cov:", sum( unlist( t.pb.pixel.cov ) ) , "\n")
 	t.pb.cov.matrix[ , !sa.polygons ] <- unlist( t.pb.pixel.cov )
-     
+
    	} ## end if t.poly.as.point < pixconfig$t.pixel.poly.dim[2]
- 
+
  	return( t.pb.cov.matrix )
 },
 pixconfig = pixconfig,
 locations = locations,
-model = model 
+model = model
 ) # end lapply
 
-t.mean.pb.cov  <- Reduce(f = "+", x = t.pb.cov.matrix.list ) / length( t.n.iter ) 
+t.mean.pb.cov  <- Reduce(f = "+", x = t.pb.cov.matrix.list ) / length( t.n.iter )
 
-return( t.mean.pb.cov ) 
+return( t.mean.pb.cov )
 
 } ## end function
 
